%define name adns
%define version 0.7
%define release 2mdk

Name:		%{name}
Summary:	Advanced, easy to use, asynchronous-capable DNS client library
Version:	%{version}
Release:	%{release}
Copyright:	GPL
Group:		System/Libraries
URL:		http://www.gnu.org/software/adns/
Source:		%{name}-%{version}.tar.bz2
BuildRoot:	/var/tmp/%{name}-%{version}
Prefix:		/usr

%description
  adns is a resolver library for C (and C++) programs. In contrast with
  the existing interfaces, gethostbyname et al and libresolv, it has the
  following features:
    * It is reasonably easy to use for simple programs which just want
      to translate names to addresses, look up MX records, etc.
    * It can be used in an asynchronous, non-blocking, manner. Many
      queries can be handled simultaneously.
    * Responses are decoded automatically into a natural representation
      for a C program - there is no need to deal with DNS packet
      formats.
    * Sanity checking (eg, name syntax checking, reverse/forward
      correspondence, CNAME pointing to CNAME) is performed
      automatically.
    * Time-to-live, CNAME and other similar information is returned in
      an easy-to-use form, without getting in the way.
    * There is no global state in the library; resolver state is an
      opaque data structure which the client creates explicitly. A
      program can have several instances of the resolver.
    * Errors are reported to the application in a way that distinguishes
      the various causes of failure properly.
    * Understands conventional resolv.conf, but this can overridden by
      environment variables.
    * Flexibility. For example, the application can tell adns to: ignore
      environment variables (for setuid programs), disable sanity checks
      eg to return arbitrary data, override or ignore resolv.conf in
      favour of supplied configuration, etc.
    * Believed to be correct ! For example, will correctly back off to
      TCP in case of long replies or queries, or to other nameservers if
      several are available. It has sensible handling of bad responses
      etc.

%package devel
Summary:	Advanced, easy to use, asynchronous-capable DNS client development library
Group: Development/C

%description devel
  adns is a resolver library for C (and C++) programs.

%prep
%setup -q


%build
if [ -d $RPM_BUILD_ROOT ]; then rm -rf $RPM_BUILD_ROOT; fi
mkdir -p $RPM_BUILD_ROOT

CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix %{prefix}
make

make check

%install
mkdir -p $RPM_BUILD_ROOT%{prefix}/bin
mkdir -p $RPM_BUILD_ROOT%{prefix}/include
mkdir -p $RPM_BUILD_ROOT%{prefix}/lib

make prefix=$RPM_BUILD_ROOT%{prefix} install
(set -e
 cd $RPM_BUILD_ROOT%{prefix}/lib
 ln -s libadns.so.? libadns.so
)
 
%post
/sbin/ldconfig


%postun
/sbin/ldconfig


%clean
if [ -d $RPM_BUILD_ROOT ]; then rm -rf $RPM_BUILD_ROOT; fi

%files
%defattr(-,root,root,0755)
%doc README TODO changelog
/usr/bin/*
/usr/lib/*.so.*

%files devel
%defattr(-,root,root,0755)
/usr/include/*
/usr/lib/*.so
/usr/lib/*.a

%changelog
* Thu Mar 23 2000 Florent Villard <warly@mandrakesoft.com> 0.7-2mdk
- rebuild

* Fri Mar  3 2000 Frederic Lepied <flepied@mandrakesoft.com> 0.7-1mdk
- 0.7.
- clean spec and split in 2 packages.

* Mon Feb 07 2000 Lenny Cartier <lenny@mandrakesoft.com>
- new in contribs
- used srpm provided by Vincent Danen <vdanen@linux-mandrake.com>

* Sun Jan 30 2000 Vincent Danen <vdanen@linux-mandrake.com>
- initial specfile
- bzip sources
